@@ -36,6 +36,9 @@ def cached_result(func):
     return f
 
 class cached_property:
+    '''Decorator for read-only property
+    @Ref: https://wiki.python.org/moin/PythonDecoratorLibrary#Cached_Properties
+    '''
     def __init__(self, fget):
         self.fget = fget
         self.__module__ = fget.__module__
